Changelog
*********

pywdpa 0.1.6
============

* Adding workflow for GitHub pages.
* Website update.

pywdpa 0.1.5
============

* Including more attributes (in particular status and date).

pywdpa 0.1.4
============

* Correcting a bug to include multipolygons.
* Get started notebook.
* Website update.

pywdpa 0.1.2 to 0.1.3
=====================

* Minor changes.
* New logo.
* New website using Sphinx.
* At: `<https://ecology.ghislainv.fr/pywdpa>`_.
* Use of reST markup language in Python docstrings.

pywdpa 0.1.1
============

* Dependence to ``python-dotenv`` has been removed.
* The ``.env`` file has to be created if using ``python-dotenv``\ .
* See `<https://pypi.org/project/python-dotenv/>`_.
* Tests have been added for functions.


pywdpa 0.1
==========

* First release of the package.
* Two functions ``.get_token()`` and ``.get_wdpa()``\ .
* Dependence to ``python-dotenv`` to manage WDPA API token.
